==> magpie-data-0.1.0-sources.jar: io/openraven/magpie/data/aws/cassandra/CassandraKeyspace.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.cassandra;

import io.openraven.magpie.data.aws.AWSResource;

import static java.lang.String.format;

@javax.persistence.Entity
@javax.persistence.Inheritance(strategy = javax.persistence.InheritanceType.TABLE_PER_CLASS)
@javax.persistence.Table(name = CassandraKeyspace.TABLE_NAME)
public class CassandraKeyspace extends AWSResource {

  protected static final String TABLE_NAME = "awscassandrakeyspace";
    public static final String RESOURCE_TYPE = "AWS::Cassandra::Keyspace";

    public CassandraKeyspace() {
    this.resourceType = RESOURCE_TYPE;

    }

    public CassandraKeyspace(String regionId, String keyspaceName) {
        this.awsRegion = regionId;
        this.arn = format("arn:aws:cassandra:keyspace:%s::%s", regionId, keyspaceName);
        this.resourceId = keyspaceName;
        this.resourceName = keyspaceName;
        this.resourceType = RESOURCE_TYPE;
    }
}

==> magpie-data-0.11.6-sources.jar: io/openraven/magpie/data/aws/cassandra/CassandraKeyspace.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.cassandra;

import io.openraven.magpie.data.aws.AWSResource;

import static java.lang.String.format;

@jakarta.persistence.Entity
@jakarta.persistence.Inheritance(strategy = jakarta.persistence.InheritanceType.TABLE_PER_CLASS)
@jakarta.persistence.Table(name = CassandraKeyspace.TABLE_NAME)
public class CassandraKeyspace extends AWSResource {

  protected static final String TABLE_NAME = "awscassandrakeyspace";
    public static final String RESOURCE_TYPE = "AWS::Cassandra::Keyspace";

    public CassandraKeyspace() {
    this.resourceType = RESOURCE_TYPE;

    }

    public CassandraKeyspace(String regionId, String keyspaceName) {
        this.awsRegion = regionId;
        this.arn = format("arn:aws:cassandra:keyspace:%s::%s", regionId, keyspaceName);
        this.resourceId = keyspaceName;
        this.resourceName = keyspaceName;
        this.resourceType = RESOURCE_TYPE;
    }
}
